Functies van TinyMCE

Functies van TinyMCE | Inhoudsopgave

Het werken met de editor komt sterk overeen met wat u gewend bent van uw tekstverwerker: Dubbel-klik op een woord in de tekst, of trek een kader met de muis terwijl u de linkerknop inhoudt om een gedeelte van de tekst te kiezen. Het aldus gemarkeerde woord of tekstfragment noemen we 'selecteerd'. Met de knoppen en stijl-keuzelijsten in de editor kunt u hiervan vervolgens de opmaak aanpassen of (indien deze reeds was toegekend) verwijderen.
De meeste functies voert u eenvoudig uit door het klikken van de knoppen (buttons) boven het tekstvenster in de editor. Hieronder vindt u van elk van deze knoppen een beknopte beschrijving.

| Gekozen tekstfragment 'Vet' (Bold) maken.
| Gekozen tekstfragment 'Cursief' (Italic) maken.
| Gekozen tekstfragment 'Onderstrepen' (Underline).
| Gekozen tekstfragment 'Doorstrepen' (Strikethrough).
| Gekozen tekstfragment naar links uitlijnen.
| Gekozen tekstfragment centreren.
| Gekozen tekstfragment naar rechts uitlijnen.
| Gekozen tekstfragment 'uitvullen' tot complete regels.

| Gekozen tekstfragment omzetten naar ongeordende (bullet-)lijst of opsomming.
| Gekozen tekstfragment omzetten naar doorgenummerde lijst.
| Inspringniveau van het gekozen tekstfragment verkleinen.
| Inspringniveau van het gekozen tekstfragment vergroten.
| De laaste bewerking ongedaan maken. De toetscombinatie CRTL-Z doet hetzelfde.
| De laatste bewerking opnieuw uitvoeren.
| Invoegen van een Link (Cross-Link) via dialoogmenu. Zie de beschrijving bij Links en verwijzingen in tekst invoegen.
| Verwijdert alle gevonden Links (Cross-Links) uit de tekstselectie.
| Anker aan de tekstselectie toekennen of wijzigen. Zie de beschrijving bij Anker Toevoegen.
| Voegt een afbeelding in. Zie de beschrijving bij Afbeeldingen invoegen.
| Schoont ongewenste opmaak en codering van de tekstselectie op. Deze functie is erg nuttig na het overkopiëren van teksten vanuit uw (Office-)tekstverwerker.
| Toont dit helpvenster met uitleg van alle functionaliteit van de editor.
| Opent het venster met de HTML-broncode voor het direct maken van wijzigingen in de achterliggende pagina-codering. Kennis van de HTML-taal is vereist.

| Voegt een nieuwe tabel met 2 rijen en kolommen in op de huidige positie in te tekst.
| Voegt een nieuwe rij toe aan de tabel boven de huidige.
| Voegt een nieuwe rij toe aan de tabel onder de huidige.
| Verwijdert de huidige rij uit de tabel.
| Voegt een nieuwe kolom toe aan de tabel voor de huidige.
| Voegt een nieuwe kolom toe aan de tabel achter de huidige.
| Verwijdert de huidige kolom uit de tabel.
| Voegt een horizontale lijn in de tekst toe.
| Verwijdert alle tekst-opmaak van de tekstselectie.
| Toon of verberg hulplijnen voor tabellen in het tekstvenster.
| Verandert het gekozen tekstfragment in Subscript.
| Verandert het gekozen tekstfragment in Superscript.
| De Karaktertabel maakt het eenvoudig invoegen van bijzondere karakters mogelijk. Zie de beschrijving bij Bijzondere karakers in de tekst invoegen.

Ga naar: Inhoudsopgave | Naar boven